@@ -18,6 +18,7 @@ For example, fourfront/deploy/generate_production_ini.py might contain:
 
 """
 
+import argparse
 import datetime
 import glob
 import io
@@ -28,10 +29,33 @@ import re
 import subprocess
 import sys
 import toml
-import argparse
 
-from dcicutils.env_utils import get_standard_mirror_env, data_set_for_env, get_bucket_env, INDEXER_ENVS
-from dcicutils.misc_utils import PRINT
+from .env_utils import get_standard_mirror_env, data_set_for_env, get_bucket_env, INDEXER_ENVS
+from .misc_utils import PRINT
+
+
+def boolean_setting(settings, key, default=None):
+    """
+    Given a setting from a .ini file and returns a boolean interpretation of it.
+    - Treats an actual python boolean as itself
+    - Using case-insensitive comparison, treats the string 'true' as True and both 'false' and '' as False.
+    - If an element is missing,
+    - Treats None the same as the option being missing, so returns the given default.
+    - Raises an error for any non-standard value. This is harsh, but it should not happen.
+    """
+    if key not in settings:
+        return default
+    setting = settings[key]
+    if isinstance(setting, str):
+        setting_lower = setting.lower()
+        if setting_lower in ("", "false"):
+            return False
+        elif setting_lower == "true":
+            return True
+        else:
+            return setting
+    else:  # booleans, None, and odd types (though we might want to consider making other types an error).
+        return setting
 
 
 class Deployer:
@@ -43,7 +67,8 @@ class Deployer:
     @classmethod
     def build_ini_file_from_template(cls, template_file_name, init_file_name,
                                      bs_env=None, bs_mirror_env=None, s3_bucket_env=None,
-                                     data_set=None, es_server=None, es_namespace=None, indexer=False):
+                                     data_set=None, es_server=None, es_namespace=None,
+                                     indexer=None, index_server=None):
         """
         Builds a .ini file from a given template file.
 
@@ -57,6 +82,7 @@ class Deployer:
             es_server (str): The server name (or server:port) for the ElasticSearch server.
             es_namespace (str): The ElasticSearch namespace to use (probably but not necessarily same as bs_env).
             indexer (bool): Whether or not we are building an ini file for an indexer.
+            index_server (bool): Whether or not we are building an ini file for an index server.
         """
         with io.open(init_file_name, 'w') as init_file_fp:
             cls.build_ini_stream_from_template(template_file_name=template_file_name,
@@ -107,10 +133,12 @@ class Deployer:
     def omittable(cls, line, expanded_line):
         return cls.PARAMETERIZED_ASSIGNMENT.match(line) and cls.EMPTY_ASSIGNMENT.match(expanded_line)
 
+    AUTO_INDEX_SERVER_TOKEN = "__index_server"
+
     @classmethod
     def build_ini_stream_from_template(cls, template_file_name, init_file_stream,
                                        bs_env=None, bs_mirror_env=None, s3_bucket_env=None, data_set=None,
-                                       es_server=None, es_namespace=None, indexer=False):
+                                       es_server=None, es_namespace=None, indexer=None, index_server=None):
         """
         Sends output to init_file_stream corresponding to the data noe would want in an ini file
         for the given template_file_name and available environment variables.
@@ -125,12 +153,12 @@ class Deployer:
             es_server: The name of an es server to use.
             es_namespace: The namespace to use on the es server. If None, this uses the bs_env.
             indexer: Whether or not we are building an ini file for an indexer.
+            indexer: Whether or not we are building an ini file for an index server.
 
         Returns: None
 
         """
 
-        # print("data_set given = ", data_set)
         es_server = es_server or os.environ.get('ENCODED_ES_SERVER', "MISSING_ENCODED_ES_SERVER")
         bs_env = bs_env or os.environ.get("ENCODED_BS_ENV", "MISSING_ENCODED_BS_ENV")
         bs_mirror_env = bs_mirror_env or os.environ.get("ENCODED_BS_MIRROR_ENV", get_standard_mirror_env(bs_env)) or ""
@@ -142,12 +170,31 @@ class Deployer:
         # If the value is missing, the empty string, or any other thing besides 'true' (in any case),
         # this value will default to the empty string, causing the line not to appear in the output file
         # because there is a special case that suppresses output of empty values. -kmp 27-Apr-2020
-        indexer = "true" if indexer or os.environ.get('ENCODED_INDEXER', "false").upper() == "TRUE" else ""
 
-        # print("data_set computed = ", data_set)
+        if indexer is None:  # If argument is not None, then it's True or False. Use that.
+            env_var_val = os.environ.get('ENCODED_INDEXER', "true").upper()
+            if env_var_val == "FALSE":
+                indexer = False
+            else:
+                indexer = True
+        indexer = "true" if indexer else ""  # this will omit the line if it's going to be False
+
+        app_version = cls.get_app_version()
+
+        if index_server is None:  # If argument is not None, then it's True or False. Use that.
+
+            if "ENCODED_INDEX_SERVER" not in os.environ and cls.AUTO_INDEX_SERVER_TOKEN in app_version:
+                index_server = True
+            else:
+                server_env_var_val = os.environ.get('ENCODED_INDEX_SERVER', "false").upper()
+                if server_env_var_val == "FALSE":
+                    index_server = False
+                else:
+                    index_server = True
+        index_server = "true" if index_server else ""  # this will omit the line if it's going to be False
 
         extra_vars = {
-            'APP_VERSION': cls.get_app_version(),
+            'APP_VERSION': app_version,
             'PROJECT_VERSION': toml.load(cls.PYPROJECT_FILE_NAME)['tool']['poetry']['version'],
             'SNOVAULT_VERSION': pkg_resources.get_distribution("dcicsnovault").version,
             'UTILS_VERSION': pkg_resources.get_distribution("dcicutils").version,
@@ -158,12 +205,13 @@ class Deployer:
             'DATA_SET': data_set,
             'ES_NAMESPACE': es_namespace,
             'INDEXER': indexer,
+            'INDEX_SERVER': index_server,
         }
 
         # if we specify an indexer name for bs_env, we did the deployment wrong and should bail
         if bs_env in INDEXER_ENVS:
             raise RuntimeError("Deployed with bs_env %s, which is an indexer env."
-                               "Re-deploy with the env you want to index and set the 'ENCODED.INDEXER'"
+                               "Re-deploy with the env you want to index and set the 'ENCODED_INDEXER'"
                                "environment variable." % bs_env)
 
         # We assume these variables are not set, but best to check first. Confusion might result otherwise.
@@ -271,9 +319,13 @@ class Deployer:
                                 help="an ElasticSearch namespace",
                                 default=None)
             parser.add_argument("--indexer",
-                                help="whether or not to deploy an indexer",
-                                action='store_true',
-                                default=False)
+                                help="whether this server does indexing at all",
+                                choices=["true", "false"],
+                                default=None)
+            parser.add_argument("--index_server",
+                                help="whether this is a standalone indexing server, only doing indexing",
+                                choices=["true", "false"],
+                                default=None)
             args = parser.parse_args()
             template_file_name = (cls.any_environment_template_filename()
                                   if args.use_any
@@ -285,11 +337,11 @@ class Deployer:
                                              bs_env=args.bs_env, bs_mirror_env=args.bs_mirror_env,
                                              s3_bucket_env=args.s3_bucket_env, data_set=args.data_set,
                                              es_server=args.es_server, es_namespace=args.es_namespace,
-                                             indexer=args.indexer)
+                                             indexer=args.indexer, index_server=args.index_server)
         except Exception as e:
             PRINT("Error (%s): %s" % (e.__class__.__name__, e))
             sys.exit(1)
 
 
 if __name__ == "__main__":
-    Deployer.main()
+    Deployer.main()  # noqa - this is just for debugging
